@@ -18,6 +18,10 @@ class LocationAPI(APIView):
     def list(self, **kwargs):
         # 用户组 列表接口
         params = parse_data(self)
+        need_pagination = eval(params.pop("need_pagination", "True"))
+        filter_fields = params.pop("filter_fields", "")
+        filter_fields = [i for i in filter_fields.split(",") if i]
+        print(filter_fields)
         # 删除原来的权限判断，因为原来的权限呗重新写了，所以不可以使用了。
         # # auth_list = {}
         # # 权限判断
@@ -53,7 +57,7 @@ class LocationAPI(APIView):
         #         params['user_id__in'] = allow_user_list
         #     else:
         #         params["user_id__not_in"] = ban_user_list
-        data, err = LocationService.location_list(params)
+        data, err = LocationService.location_list(params, need_pagination=need_pagination, fields=filter_fields)
         if err:
             return util_response(err=1000, msg=err)
         return util_response(data=data)
@@ -90,4 +94,3 @@ class LocationAPI(APIView):
         params = {"thread_id_list": [1, 2]}
         data, err = LocationService.location_list(params, False)
         return util_response(data=data)
-
