@@ -12,6 +12,8 @@ class Location(models.Model):
     id = models.AutoField(primary_key=True)
     region_code = models.BigIntegerField('行政ID', null=False, default=0)
     thread_id = models.IntegerField('信息ID', null=False, default=0)
+    category_id = models.IntegerField('类别ID', null=False, default=0)
+    classify_id = models.IntegerField('分类ID', null=False, default=0)
     name = models.CharField('名称', null=False, default="", max_length=50)
     address = models.CharField('详细地址', null=False, default="", max_length=255)
     coordinate_type = models.IntegerField('定位类型', null=False, default=84)
