@@ -14,7 +14,7 @@ urlpatterns = [
     re_path('^add/?$', LocationAPI.as_view()),  # 创建定位
     re_path('^del/?(?P<id>\d+)?$', LocationAPI.as_view()),  # 删除定位
     re_path('^edit/?(?P<id>\d+)?$', LocationAPI.as_view()),  # 修改定位
-    re_path('^list/$', LocationAPI.list),  # 定位点 分页条件查询
+    re_path('^list/?$', LocationAPI.list),  # 定位点 分页条件查询
 
     # 边界
     re_path('^boundary/?(?P<id>\d+)?$', BoundaryAPI.as_view()),
